@@ -1,6 +1,6 @@
 /*
 
- $Id: arch.cpp,v 1.32 2001/02/07 20:53:47 mjarrett Exp $
+ $Id: arch.cpp,v 1.35 2001/07/17 18:46:06 maragato Exp $
 
  ark -- archiver for the KDE project
 
@@ -9,6 +9,7 @@
  1997-1999: Rob Palmbos palm9744@kettering.edu
  1999: Francois-Xavier Duranceau duranceau@kde.org
  1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
+ 2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -26,24 +27,38 @@
 
 */
 
+// C includes
 #include <stdlib.h>
 #include <time.h>
 
+// QT includes
 #include <qapplication.h>
 #include <qfile.h>
-#include <qregexp.h>
 #include <qlist.h>
+#include <qregexp.h>
+#include <qstring.h>
 
+// KDE includes
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kmimemagic.h>
 #include <klocale.h>
-
-#include <stdlib.h>
+#include <kprocess.h>
 
 // ark includes
 #include "arch.h"
-#include "viewer.h"
+#include "arksettings.h"
+#include "filelistview.h"
+#include "arkwidgetbase.h"
+
+// the archive types
+#include "tar.h"
+#include "zip.h"
+#include "lha.h"
+#include "compressedfile.h"
+#include "zoo.h"
+#include "rar.h"
+#include "ar.h"
 
 
 Arch::ArchColumns::ArchColumns(int col, QRegExp reg, int length, bool opt) :
@@ -51,19 +66,18 @@ Arch::ArchColumns::ArchColumns(int col, QRegExp reg, int length, bool opt) :
 {
 }
 
-Arch::Arch( ArkSettings *_settings, Viewer *_viewer,
-	    const QString & _fileName )
-  : m_filename(_fileName), m_settings(_settings), m_gui(_viewer),
-    m_bReadOnly(false), m_bNotifyWhenDeleteFails(true),
+
+Arch::Arch(ArkSettings *_settings, ArkWidgetBase *_viewer,
+	   const QString & _fileName )
+  : m_filename(_fileName), m_buffer(""), m_settings(_settings),
+    m_gui(_viewer), m_bReadOnly(false), m_bNotifyWhenDeleteFails(true),
     m_header_removed(false), m_finished(false),
-    m_numCols(0), m_dateCol(-1), m_fixYear(-1), m_fixMonth(-1),
-    m_fixDay(-1), m_fixTime(-1), m_repairYear(-1), m_repairMonth(-1),
-    m_repairTime(-1)
+	m_numCols(0), m_dateCol(-1), m_fixYear(-1), m_fixMonth(-1),
+	m_fixDay(-1), m_fixTime(-1), m_repairYear(-1), m_repairMonth(-1),
+	m_repairTime(-1)
 
 {
-  kdDebug(1601) << "+Arch::Arch" << endl;
-  m_archCols.setAutoDelete(true);
-  kdDebug(1601) << "-Arch::Arch" << endl;
+	m_archCols.setAutoDelete(true);	// To check: it still leaky here???
 }
 
 Arch::~Arch()
@@ -151,9 +165,10 @@ void Arch::slotDeleteExited(KProcess *_kp)
       if(stderrIsError())
 	{
 	  QApplication::restoreOverrideCursor();
-	  KMessageBox::error( 0, i18n("You probably don't have sufficient permissions.\n"
-				      "Please check the file owner and the integrity\n"
-				      "of the archive.") );
+	  KMessageBox::error(m_gui->getArkWidget(),
+		 i18n("You probably don't have sufficient permissions.\n"
+		      "Please check the file owner and the integrity\n"
+		      "of the archive.") );
 	}
       else
 	bSuccess = true;
@@ -163,8 +178,8 @@ void Arch::slotDeleteExited(KProcess *_kp)
       if (m_bNotifyWhenDeleteFails)
 	{
 	  QApplication::restoreOverrideCursor();
-	  KMessageBox::sorry( (QWidget *)0,
-			      i18n("Deletion failed"), i18n("Error") );
+	  KMessageBox::sorry(m_gui->getArkWidget(), i18n("Deletion failed"),
+			     i18n("Error") );
 	}
       else bSuccess = true;
     }
@@ -191,7 +206,9 @@ void Arch::slotExtractExited(KProcess *_kp)
       if(stderrIsError())
 	{
 	  QApplication::restoreOverrideCursor();
-	  int ret = KMessageBox::warningYesNo( (QWidget *) 0, i18n("Sorry, the extract operation failed.\nDo you wish to view the shell output?"), i18n("Error"));
+	  int ret = KMessageBox::warningYesNo(m_gui->getArkWidget(),
+		i18n("Sorry, the extract operation failed.\n"
+		     "Do you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
 	    m_gui->viewShellOutput();
 	}
@@ -221,9 +238,10 @@ void Arch::slotAddExited(KProcess *_kp)
       if(stderrIsError())
 	{
 	  QApplication::restoreOverrideCursor();
-	  KMessageBox::error( 0, i18n("You probably don't have sufficient permissions\n"
-				      "Please check the file owner and the integrity\n"
-				      "of the archive.") );
+	  KMessageBox::error(m_gui->getArkWidget(),
+			     i18n("You probably don't have sufficient permissions\n"
+				  "Please check the file owner and the integrity\n"
+				  "of the archive."));
 	}
       else
 	bSuccess = true;
@@ -231,7 +249,9 @@ void Arch::slotAddExited(KProcess *_kp)
   else
     {
       QApplication::restoreOverrideCursor();
-      int ret = KMessageBox::warningYesNo( (QWidget *) 0, i18n("Sorry, the add operation failed.\nDo you wish to view the shell output?"), i18n("Error"));
+      int ret = KMessageBox::warningYesNo(m_gui->getArkWidget(),
+		 i18n("Sorry, the add operation failed.\n"
+		      "Do you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
 	    m_gui->viewShellOutput();
     }
@@ -257,6 +277,7 @@ void Arch::slotReceivedOutput(KProcess*, char* _data, int _length)
   _data[_length] = c;
 }
 
+
 void Arch::slotReceivedTOC(KProcess*, char* _data, int _length)
 {
   char c = _data[_length];
@@ -303,6 +324,7 @@ void Arch::slotReceivedTOC(KProcess*, char* _data, int _length)
   }
   if(!m_finished)
 	m_buffer = (_data + startChar);	// Copy what's left of the buffer
+
   _data[_length] = c;
 }
 
@@ -337,6 +359,7 @@ bool Arch::processLine(const QCString &line)
 	columns[curCol->colRef] = line.mid(strpos, len);
   }
 
+
   if(m_dateCol >= 0)
   {
     QString year = m_repairYear >= 0?
@@ -358,7 +381,7 @@ bool Arch::processLine(const QCString &line)
     {
       list.append(columns[i]);
     }
-  m_gui->add(&list); // send the entry to the GUI
+  m_gui->listingAdd(&list); // send the entry to the GUI
 
   return true;
 }
@@ -366,7 +389,6 @@ bool Arch::processLine(const QCString &line)
 
 
 
-
 /// UTILS
 
 
@@ -376,7 +398,7 @@ QString Utils::getTimeStamp(const QString &_month,
 {
   // Make the date format sortable.
   // Month is in _month, day is in _day.
-  // In _yearOrTime is either a year or a time. 
+  // In _yearOrTime is either a year or a time.
   // If it's March, we'll see the year for all dates up to October 1999.
   // (five months' difference - e.g., if it's Apr, then get years up to Nov)
 
@@ -413,10 +435,10 @@ QString Utils::getTimeStamp(const QString &_month,
 
       timestamp = "??:??";
     }
-    
+
   QString retval;
   retval.sprintf("%s-%.2d-%.2d %s",
-		 year.utf8().data(), nMonth, nDay, 
+		 year.utf8().data(), nMonth, nDay,
 		 timestamp.utf8().data());
   return retval;
 }
@@ -434,11 +456,11 @@ int Utils::getMonth(const char *strMonth)
     }
   return 0;
 }
-  
+
 // This function gets the year from an LHA or ls -l timestamp.
 // Note: LHA doesn't seem to display the year if the file is more
 // than 6 months into the future, so this will fail to give the correct
-// year (of course it is hoped that there are not too many files lying 
+// year (of course it is hoped that there are not too many files lying
 // around from the future).
 
 int Utils::getYear(int theMonth, int thisYear, int thisMonth)
@@ -470,95 +492,147 @@ QString Utils::fixYear(const char *strYear)
   return fourDigits;
 }
 
-ArchType getArchType( const QString & archname, QString &extension)
+
+Arch *Arch::archFactory(ArchType aType, ArkSettings *settings,
+			ArkWidgetBase *parent, const QString &filename)
 {
-  if ((archname.right(4) == ".tgz") || (archname.right(4) == ".tzo")
-       || (archname.right(4) == ".taz")
-       || (archname.right(4) == ".tar"))
-    {
-      extension = archname.right(4);
-      return TAR_FORMAT;
-    }
-  if (archname.right(6) == ".tar.Z")
-    {
-      extension = ".tar.Z";
-      return TAR_FORMAT;
-    }
-  if ((archname.right(7) == ".tar.gz")
-      || (archname.right(7) == ".tar.bz"))
-    {
-      extension = archname.right(7);
-      return TAR_FORMAT;
-    }
-  if ((archname.right(8) == ".tar.bz2")
-      || (archname.right(8) == ".tar.lzo"))
-    {
-      extension = archname.right(8);
-      return TAR_FORMAT;
-    }
-  if ((archname.right(4) == ".lha") || (archname.right(4) == ".lzh"))
-    {
-      extension = archname.right(4);
-      return LHA_FORMAT;
-    }
-  if ((archname.right(4) == ".zip") || (archname.right(4) == ".xpi"))
-    {
-      extension = archname.right(4);
-      return ZIP_FORMAT;
-    }
-  if ((archname.right(3) == ".gz") || (archname.right(3) == ".bz"))
-    {
-      extension = archname.right(3);
-      return COMPRESSED_FORMAT;
-    }
-  if ((archname.right(4) == ".bz2") || (archname.right(4) == ".lzo"))
-    {
-      extension = archname.right(4);
-      return COMPRESSED_FORMAT;
-    }
-  if (archname.right(2) == ".Z")
-    {
-      extension = ".Z";
-      return COMPRESSED_FORMAT;
-    }
-  if (archname.right(4) == ".zoo")
-    {
-      extension = ".zoo";
-      return ZOO_FORMAT;
-    }
-  if (archname.right(4) == ".rar")
-    {
-      extension = ".rar";
-      return RAR_FORMAT;
-    }
-  if (archname.right(2) == ".a")
-    {
-      extension = ".a";
-      return AA_FORMAT;
-    }
-
-  // now try using magic
-
-  KMimeMagic *mimePtr = KMimeMagic::self();
-  KMimeMagicResult * mimeResultPtr = mimePtr->findFileType(archname);
-  QString mimetype = mimeResultPtr->mimeType();
-  extension = QString::null;
-
-  kdDebug(1601) << "The mime type is " << mimetype << endl;
-
-  if (mimetype == "application/x-rar")
-    return RAR_FORMAT;
-  if (mimetype == "application/x-lha")
-    return LHA_FORMAT;
-  if (mimetype == "application/x-archive")
-    return AA_FORMAT;
-  if (mimetype == "application/x-tar")
-    return TAR_FORMAT;
-  if (mimetype == "application/x-zip")
-    return ZIP_FORMAT;
-  return UNKNOWN_FORMAT;
+	switch(aType)
+	{
+	case TAR_FORMAT: return new TarArch(settings, parent, filename);
+	case ZIP_FORMAT: return new ZipArch(settings, parent, filename);
+	case LHA_FORMAT: return new LhaArch(settings, parent, filename);
+	case COMPRESSED_FORMAT: return new CompressedFile(settings,
+							  parent, filename);
+	case ZOO_FORMAT: return new ZooArch(settings, parent, filename);
+	case RAR_FORMAT: return new RarArch(settings, parent, filename);
+	case AA_FORMAT: return new ArArch(settings, parent, filename);
+	case UNKNOWN_FORMAT:
+	default: return 0;
+	}
 }
 
+ArchType Arch::getArchType(const QString &archname, QString &extension,
+                           const KURL &realURL)
+{
+  // Get the non-temporary name. Since we don't actually open anything
+  // with it, the path information is irrelevant
+  QString fileName = realURL.isEmpty() ? archname : realURL.filename();
+
+  ArchType extType = getArchTypeByExtension(fileName, extension);
+
+  if (UNKNOWN_FORMAT == extType)
+  {
+    // now try using magic
+    KMimeMagic *mimePtr = KMimeMagic::self();
+    KMimeMagicResult * mimeResultPtr = mimePtr->findFileType(archname);
+    QString mimetype = mimeResultPtr->mimeType();
+    extension = QString::null;
+
+    kdDebug(1601) << "The mime type is " << mimetype << endl;
+
+    if (mimetype == "application/x-rar")
+      extType = RAR_FORMAT;
+    if (mimetype == "application/x-lha")
+      extType = LHA_FORMAT;
+    if (mimetype == "application/x-archive")
+      extType = AA_FORMAT;
+    if (mimetype == "application/x-tar")
+      extType = TAR_FORMAT;
+    if (mimetype == "application/x-zip")
+      extType = ZIP_FORMAT;
+  }
+
+  return extType;
+}
+
+
+/**
+* Try to determine the archive type by the extension. We separate
+* this functionality out, to make it as easy to use as the MIME
+* magic.
+*/
+ArchType Arch::getArchTypeByExtension(const QString &archname,
+                                      QString &extension)
+{
+	if ((archname.right(4) == ".tgz") || (archname.right(4) == ".tzo")
+	    || (archname.right(4) == ".taz")
+	    || (archname.right(4) == ".tar"))
+	{
+		extension = archname.right(4);
+		return TAR_FORMAT;
+	}
+	/* Patch by Matthias Belitz for handling KOffice docs */
+	/*  if ((archname.right(4) == ".kil") || (archname.right(4) == ".kwd")
+	     || (archname.right(4) == ".kwt")
+	     || (archname.right(4) == ".ksp") || (archname.right(4) == ".kpr")
+	     || (archname.right(4) == ".kpt"))
+	{
+		extension = archname.right(4);
+		return TAR_FORMAT;
+	}*/
+	if (archname.right(6) == ".tar.Z")
+	{
+		extension = ".tar.Z";
+		return TAR_FORMAT;
+	}
+	if ((archname.right(7) == ".tar.gz")
+	    || (archname.right(7) == ".tar.bz"))
+	{
+		extension = archname.right(7);
+		return TAR_FORMAT;
+	}
+	if ((archname.right(8) == ".tar.bz2")
+	    || (archname.right(8) == ".tar.lzo"))
+	{
+		extension = archname.right(8);
+		return TAR_FORMAT;
+	}
+	if ((archname.right(4) == ".lha") || (archname.right(4) == ".lzh"))
+	{
+		extension = archname.right(4);
+		return LHA_FORMAT;
+	}
+	if ( ( archname.right( 4 ) == ".zip" ) ||
+             ( archname.right( 4 ) == ".xpi" ) ||
+             ( archname.right( 4 ) == ".exe" ) ||
+             ( archname.right( 4 ) == ".EXE" ) )
+	{
+		extension = archname.right(4);
+		return ZIP_FORMAT;
+	}
+	if ((archname.right(3) == ".gz") || (archname.right(3) == ".bz"))
+	{
+		extension = archname.right(3);
+		return COMPRESSED_FORMAT;
+	}
+	if ((archname.right(4) == ".bz2") || (archname.right(4) == ".lzo"))
+	{
+		extension = archname.right(4);
+		return COMPRESSED_FORMAT;
+	}
+	if (archname.right(2) == ".Z")
+	{
+		extension = ".Z";
+		return COMPRESSED_FORMAT;
+	}
+	if (archname.right(4) == ".zoo")
+	{
+		extension = ".zoo";
+		return ZOO_FORMAT;
+	}
+	if (archname.right(4) == ".rar")
+	{
+		extension = ".rar";
+		return RAR_FORMAT;
+	}
+	if (archname.right(2) == ".a")
+	{
+		extension = ".a";
+		return AA_FORMAT;
+	}
+
+	return UNKNOWN_FORMAT;
+}
 
 
 #include "arch.moc"
