@@ -1,7 +1,7 @@
 
 /*
 
- $Id: mail.h,v 1.2 1997/12/12 15:54:12 denis Exp $
+ $Id: mail.h,v 1.5 1999/12/03 09:23:42 waba Exp $
 
  Copyright (C) Bernd Johannes Wuebben
                wuebben@math.cornell.edu
@@ -24,49 +24,36 @@
  */
 
 
+
 #ifndef _MAIL_DLG_H_
 #define _MAIL_DLG_H_
 
-#include <qgrpbox.h> 
-#include <qchkbox.h>
-#include <qdialog.h>
-#include <qlined.h>
-#include <qpushbt.h>
-#include <qpainter.h>
-#include <qlabel.h>
-#include <qframe.h>
-#include "kedit.h"
+#include <qlineedit.h>
+#include <kdialogbase.h>
 
-class Mail : public QDialog
+class QLabel;
+class TopLevel;
+
+class Mail : public KDialogBase
 {
-    Q_OBJECT
+  Q_OBJECT
 
-public:
+  public:
+    Mail( TopLevel *parent = 0, const char *name=0, bool modal=true );
 
-    Mail ( TopLevel *parent = 0, const char *name=0);
+    QString getRecipient( void ) {return recipient->text();};
+    QString getSubject( void ) {return subject->text();};
 
+  public:
     QLineEdit 	*recipient;
     QLineEdit 	*subject;
     QLabel 	*subjectlabel;
-    QString getRecipient(){return recipient->text();};
-    QString getSubject(){return subject->text();};
-
-protected:
 
+  protected:
     void focusInEvent( QFocusEvent *);
-    void resizeEvent ( QResizeEvent *);
 
-private:
-
-    QPushButton *ok, *cancel;
-    QGroupBox 	*frame1;
-
-
-
-public slots:
-     
-    void cancel_slot();
-    void ok_slot();
+  public slots:
+    virtual void slotUser1( void );
 
 };
 
