@@ -95,7 +95,8 @@ KfindTabWidget::KfindTabWidget(const KURL & url,
     grid->addMultiCellLayout( subgrid, 2, 2, 1, 2 );
     subgrid->addWidget( subdirsCb );
     subgrid->addSpacing( KDialog::spacingHint() );
-    subgrid->addWidget( caseSensCb, 1 );
+    subgrid->addWidget( caseSensCb);
+    subgrid->addStretch(1);
     // Signals
 
     connect( browseB, SIGNAL(clicked()),
