@@ -8,6 +8,7 @@
 #define KFWIN_H
 
 #include <klistview.h>
+#include <kfileitem.h>
 
 class KfArchiver;
 class QPixmap;
@@ -16,12 +17,13 @@ class QFileInfo;
 class KfFileLVI : public QListViewItem
 {
  public:
-  KfFileLVI(KListView* lv, QString file);
+  KfFileLVI(KListView* lv, const KFileItem &item);
   ~KfFileLVI();
 
   QString key(int column, bool) const;
 
   QFileInfo *fileInfo;
+  KFileItem fileitem;
 };
 
 class KfindWindow: public   KListView
@@ -33,30 +35,24 @@ public:
   void beginSearch();
   void endSearch();
 
-  void copySelection();
-
-  void insertItem(QString str);
+  void insertItem(const KFileItem &item);
 
 public slots:
-  void selectAll();
-  void unselectAll();
+  void copySelection();
+  void slotContextMenu(KListView *,QListViewItem *item,const QPoint&p);
 
 private slots:
   void deleteFiles();
   void fileProperties();
   void openFolder();
   void saveResults();
-  void addToArchive();
   void openBinding();
   void selectionHasChanged();
 
 protected:
   virtual void resizeEvent(QResizeEvent *e);
-  virtual void contentsMousePressEvent(QMouseEvent *e);
-  virtual void contentsMouseReleaseEvent(QMouseEvent *e);
-  virtual void contentsMouseMoveEvent(QMouseEvent *e);
 
-  QList<KfFileLVI> * selectedItems();
+  virtual QDragObject *dragObject() const;
 
 signals:
   void resultSelected(bool);
@@ -64,11 +60,7 @@ signals:
 private:
   bool haveSelection;
   bool m_pressed;
-  void execAddToArchive(KfArchiver *arch, QString filename);
   void resetColumns(bool init);
-
-  QList<KfFileLVI> mySelectedItems;
-
 };
 
 #endif
