@@ -476,16 +476,19 @@ void CExportDialog::browserClicked( void )
   }
   else
   {
-    KURL tmpurl = KFileDialog::getSaveURL( mWorkDir, "*", topLevelWidget());
-
-    url = tmpurl.url();
+    url = KFileDialog::getSaveFileName( mWorkDir, "*", topLevelWidget() );
   }
 
   if( url.isEmpty() )
+  {
     return;
+  }
   
   int index = url.findRev( '/' );
-  if( index != -1 ) { mWorkDir = url.left( index+1 ); }
+  if( index != -1 ) 
+  { 
+    mWorkDir = url.left( index+1 ); 
+  }
   mDestination.fileInput->setText( url );
 }
 
