@@ -778,7 +778,7 @@ void CHexEditorWidget::insertFile( void )
 
   if( file.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
 
@@ -1266,7 +1266,7 @@ void CHexEditorWidget::encode( CConversion::EMode mode )
     QString msg = i18n(""
       "The encoding you have selected is not reversible.\n"
       "If you revert to the original encoding later, there is no\n"
-      "guarantee that data can be restored to its original state.\n\n"
+      "guarantee that the data can be restored to the original state.\n\n"
       "Proceed?");
     int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
 					   i18n("Encode") );
@@ -1876,7 +1876,7 @@ void CHexEditorWidget::recordView( void )
 {
   QString msg = i18n(""
    "Not available yet!\n"
-   "Define a record (structure) and fill it with data from document" );
+   "Define a record (structure) and fill it with data from the document." );
   KMessageBox::sorry( topLevelWidget(), msg, i18n("Record viewer") );
 }
 
@@ -2218,7 +2218,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
   QFile file( diskPath );
   if( file.open( IO_ReadOnly | IO_Raw ) == false )
   {
-    QString msg = i18n("An error occured while trying to open file.");
+    QString msg = i18n("An error occured while trying to open the file.");
     msg += "\n" + diskPath;
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
@@ -2283,7 +2283,7 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
   QFile file( diskPath );
   if( file.open( IO_WriteOnly | IO_Raw | IO_Truncate ) == false )
   {
-    QString msg = i18n("An error occured while trying to open file.");
+    QString msg = i18n("An error occured while trying to open the file.");
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
     return( false );
   }
