@@ -866,7 +866,7 @@ void CPrinterDialog::browserClicked( void )
 
   if( !file.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
 
@@ -887,7 +887,7 @@ void CPrinterDialog::appBrowserClicked( void )
   
   if( !file.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
   
@@ -915,7 +915,7 @@ void CPrinterDialog::textFormatClicked( int id )
 
 void CPrinterDialog::paperTypeChanged( int id )
 {
-  const SPageSize &size = paperSize( (QPrinter::PageSize)id );
+  const SPageSize &size = paperSize( (KPrinter::PageSize)id );
   QString msg;
   
   if( size.isInch == true )
@@ -990,24 +990,24 @@ void CPrinterDialog::slotUser1( void ) // Print
 
   if( mOption.portraitRadio->isChecked() == true )
   {
-    mPrinter.setOrientation( QPrinter::Portrait );
+    mPrinter.setOrientation( KPrinter::Portrait );
   }
   else
   {
-    mPrinter.setOrientation( QPrinter::Landscape );
+    mPrinter.setOrientation( KPrinter::Landscape );
   }
 
   mPrinter.setPageSize( 
-    (QPrinter::PageSize)mOption.paperSelector->currentItem() );
+    (KPrinter::PageSize)mOption.paperSelector->currentItem() );
   mPrinter.setFullPage( true ); // I use my own marings
   
   if( mOption.firstRadio->isChecked() == true )
   {
-    mPrinter.setPageOrder( QPrinter::FirstPageFirst );
+    mPrinter.setPageOrder( KPrinter::FirstPageFirst );
   }
   else
   {
-    mPrinter.setPageOrder( QPrinter::LastPageFirst );
+    mPrinter.setPageOrder( KPrinter::LastPageFirst );
   }
 
   mPrinter.setNumCopies( mOption.pageSpin->value() );
@@ -1032,17 +1032,17 @@ void CPrinterDialog::slotUser1( void ) // Print
 
   if( mOption.colorRadio->isChecked() == true )
   {
-    mPrinter.setColorMode( QPrinter::Color );
+    mPrinter.setColorMode( KPrinter::Color );
     mPrinter.setPrintBackWhite( false );
   }
   else if( mOption.grayRadio->isChecked() == true )
   {
-    mPrinter.setColorMode( QPrinter::GrayScale );
+    mPrinter.setColorMode( KPrinter::GrayScale );
     mPrinter.setPrintBackWhite( false );
   }
   else
   {
-    mPrinter.setColorMode( QPrinter::Color );
+    mPrinter.setColorMode( KPrinter::Color );
     mPrinter.setPrintBackWhite( true );
   }
 
@@ -1272,18 +1272,18 @@ void CPrinterDialog::paperType( QStringList &list )
 
 
 const CPrinterDialog::SPageSize CPrinterDialog::paperSize( 
-			        QPrinter::PageSize pageSize )
+			        KPrinter::PageSize pageSize )
 {
 
-  QPrinter printer;
+  KPrinter printer;
   printer.setPageSize( pageSize );
   printer.setFullPage( true ); // I use my own margins
 
   QPaintDeviceMetrics paintMetric( &printer );
   SPageSize size;
 
-  if( pageSize == QPrinter::Executive || pageSize == QPrinter::Legal ||
-      pageSize == QPrinter::Letter )
+  if( pageSize == KPrinter::Executive || pageSize == KPrinter::Legal ||
+      pageSize == KPrinter::Letter )
   {
     size.width  = (double)paintMetric.widthMM() / 25.4;
     size.height = (double)paintMetric.heightMM() / 25.4;
@@ -1298,7 +1298,7 @@ const CPrinterDialog::SPageSize CPrinterDialog::paperSize(
   return( size );
 
   #if 0
-  static SPageSize size[ QPrinter::Tabloid+2 ] = 
+  static SPageSize size[ KPrinter::Tabloid+2 ] = 
   {
     {210,  297},  // A4
     {182,  257},  // B5
@@ -1333,7 +1333,7 @@ const CPrinterDialog::SPageSize CPrinterDialog::paperSize(
     {0,    0},    // Unknown
   };
 
-  return( size[ pageSize > QPrinter::Tabloid ? QPrinter::Tabloid : pageSize ]);
+  return( size[ pageSize > KPrinter::Tabloid ? KPrinter::Tabloid : pageSize ]);
   #endif
 }
 #include "printerdialog.moc"
