@@ -997,7 +997,7 @@ void KJotsMain::writeBook()
 
     if ( !url.isLocalFile() )
     {
-      KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+      KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
       return;
     }
 
@@ -1040,7 +1040,7 @@ void KJotsMain::writePage()
 
     if( !url.isLocalFile() )
     {
-      KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+      KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
       return;
     }
 
