@@ -145,6 +145,9 @@ void OptionDialog::setupPrinterPage( void )
   mPrinter.printerCombo = new  QComboBox( page, "printer" );
   vlay1->addWidget( mPrinter.printerCombo );
 
+  connect( mPrinter.printerCombo, SIGNAL( highlighted(const QString&) ),
+           SLOT( setPrinter(const QString&) ));
+
   vlay1->addStretch(10);
 
   label = new QLabel( i18n("Density:"), page );
@@ -654,5 +657,7 @@ void OptionDialog::initializeButtonClicked( void )
   mState.initialize();
 }
 
-
-
+void OptionDialog::setPrinter(const QString& str)
+{
+  mState.setPrinter( str );
+}
