@@ -6,7 +6,7 @@
 class ButtonGroup : public QButtonGroup 
 {
   public:
-    ButtonGroup(const char *title, QWidget *parent);
+    ButtonGroup(const QString & title, QWidget *parent);
 
   protected:
     virtual void showEvent( QShowEvent * );
